@@ -7,10 +7,10 @@
 *************************************************************************/
 #pragma once
 
-#include<yade/lib/base/Math.hpp>
-#include<yade/lib/serialization/Serializable.hpp>
-#include<yade/lib/multimethods/Indexable.hpp>
-#include<yade/core/Dispatcher.hpp>
+#include<lib/base/Math.hpp>
+#include<lib/serialization/Serializable.hpp>
+#include<lib/multimethods/Indexable.hpp>
+#include<core/Dispatcher.hpp>
 
 /*! Interface for approximate body locations in space
 
