@@ -2,7 +2,7 @@
 
 #pragma once
 
-#include<yade/lib/triangulation/FlowBoundingSphere.hpp>//include after #define XVIEW
+#include <lib/triangulation/FlowBoundingSphere.hpp>//include after #define XVIEW
 // #include "Timer.h"
 // #include "PeriodicTesselation.h"
 // #include "basicVTKwritter.hpp"
@@ -179,6 +179,9 @@ void PeriodicFlow<_Tesselation>::computePermeability()
 	for (VCellIterator cellIt=T[currentTes].cellHandles.begin(); cellIt!=T[currentTes].cellHandles.end(); cellIt++){
 			CellHandle& cell = *cellIt;
 			Point& p1 = cell->info();
+			if (cell->info().blocked) {
+				this->setBlocked(cell);}
+			if (cell->info().isGhost) {cerr<<"skipping a ghost"<<endl; continue;}
 			for (int j=0; j<4; j++){
 				neighbourCell = cell->neighbor(j);
 				Point& p2 = neighbourCell->info();
@@ -202,6 +205,9 @@ void PeriodicFlow<_Tesselation>::computePermeability()
 					W[1]->info().isFictious ? 0 : 0.5*v1.weight()*acos((v0-v1)*(v2-v1)/sqrt((v1-v0).squared_length()*(v2-v1).squared_length())),
 					W[2]->info().isFictious ? 0 : 0.5*v2.weight()*acos((v0-v2)*(v1-v2)/sqrt((v1-v2).squared_length()*(v2-v0).squared_length())));
 #endif
+					//FIXME: it should be possible to skip completely blocked cells, currently the problem is it segfault for undefined areas
+					//if (cell->info().blocked) continue;//We don't need permeability for blocked cells, it will be set to zero anyway
+
 					pass+=1;
 					CVector l = p1 - p2;
 					distance = sqrt(l.squared_length());
@@ -219,14 +225,14 @@ void PeriodicFlow<_Tesselation>::computePermeability()
 						const CVector& Surfk = cell->info().facetSurfaces[j];
 						Real area = sqrt(Surfk.squared_length());
 						const CVector& crossSections = cell->info().facetSphereCrossSections[j];
-							Real S0=0;
-							S0=checkSphereFacetOverlap(v0,v1,v2);
-							if (S0==0) S0=checkSphereFacetOverlap(v1,v2,v0);
-							if (S0==0) S0=checkSphereFacetOverlap(v2,v0,v1);
-							//take absolute value, since in rare cases the surface can be negative (overlaping spheres)
-							fluidArea=abs(area-crossSections[0]-crossSections[1]-crossSections[2]+S0);
-							cell->info().facetFluidSurfacesRatio[j]=fluidArea/area;
-							k=(fluidArea * pow(radius,2)) / (8*viscosity*distance);
+						Real S0=0;
+						S0=checkSphereFacetOverlap(v0,v1,v2);
+						if (S0==0) S0=checkSphereFacetOverlap(v1,v2,v0);
+						if (S0==0) S0=checkSphereFacetOverlap(v2,v0,v1);
+						//take absolute value, since in rare cases the surface can be negative (overlaping spheres)
+						fluidArea=abs(area-crossSections[0]-crossSections[1]-crossSections[2]+S0);
+						cell->info().facetFluidSurfacesRatio[j]=fluidArea/area;
+						k=(fluidArea * pow(radius,2)) / (8*viscosity*distance);
 						meanDistance += distance;
 						meanRadius += radius;
 						meanK += k*kFactor;
@@ -234,7 +240,7 @@ void PeriodicFlow<_Tesselation>::computePermeability()
 					if (k<0 && debugOut) {surfneg+=1;
 					cout<<"__ k<0 __"<<k<<" "<<" fluidArea "<<fluidArea<<" area "<<area<<" "<<crossSections[0]<<" "<<crossSections[1]<<" "<<crossSections[2] <<" "<<W[0]->info().id()<<" "<<W[1]->info().id()<<" "<<W[2]->info().id()<<" "<<p1<<" "<<p2<<" test "<<test<<endl;}
 					     
-					} else  cout <<"infinite K2! surfaces will be missing (FIXME)"<<endl; k = infiniteK;
+					} else  {cout <<"infinite K2! surfaces will be missing (FIXME)"<<endl; k = infiniteK;}
 					//Will be corrected in the next loop
 					(cell->info().kNorm())[j]= k*kFactor;
 					if (!neighbourCell->info().isGhost) (neighbourCell->info().kNorm())[Tri.mirror_index(cell, j)]= (cell->info().kNorm())[j];
