@@ -5,7 +5,7 @@
 *  This program is free software; it is licensed under the terms of the  *
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
-#include<yade/pkg/common/Collider.hpp>
+#include<pkg/common/Collider.hpp>
 
 YADE_PLUGIN((Collider));
 
