@@ -1,8 +1,8 @@
 // 2009 © Václav Šmilauer <eudoxos@arcig.cz> 
 // 2013 © Bruno Chareyre <bruno.chareyre@hmg.inpg.fr>
 #pragma once
-#include<yade/pkg/common/Collider.hpp>
-#include<yade/core/Scene.hpp>
+#include<pkg/common/Collider.hpp>
+#include<core/Scene.hpp>
 class InteractionContainer;
 
 
