@@ -1,9 +1,9 @@
 /* LucScholtes2010  */
 
 #include"JointedCohesiveFrictionalPM.hpp"
-#include<yade/core/Scene.hpp>
-#include<yade/pkg/dem/ScGeom.hpp>
-#include<yade/core/Omega.hpp>
+#include<core/Scene.hpp>
+#include<pkg/dem/ScGeom.hpp>
+#include<core/Omega.hpp>
 
 YADE_PLUGIN((JCFpmMat)(JCFpmState)(JCFpmPhys)(Ip2_JCFpmMat_JCFpmMat_JCFpmPhys)(Law2_ScGeom_JCFpmPhys_JointedCohesiveFrictionalPM));
 
@@ -41,9 +41,18 @@ bool Law2_ScGeom_JCFpmPhys_JointedCohesiveFrictionalPM::go(shared_ptr<IGeom>& ig
 	}
 	
 	if ( smoothJoint && phys->isOnJoint ) {
-	  if ( phys->more || ( phys->jointCumulativeSliding > (2*min(geom->radius1,geom->radius2)) ) ) {
-	    return false;
-	    } else { 
+	  if ( phys->more || ( phys-> jointCumulativeSliding > (2*min(geom->radius1,geom->radius2)) ) ) { 
+	    if (!neverErase) return false; 
+	    else {
+	      phys->shearForce = Vector3r::Zero();
+	      phys->normalForce = Vector3r::Zero();
+	      phys->isCohesive =0;
+	      phys->FnMax = 0;
+	      phys->FsMax = 0;
+	      return true;
+	      }
+	  }
+	  else { 
 	    D = phys->initD - std::abs((b1->state->pos - b2->state->pos).dot(phys->jointNormal)); 
 	    }
 	} else { 
@@ -51,10 +60,17 @@ bool Law2_ScGeom_JCFpmPhys_JointedCohesiveFrictionalPM::go(shared_ptr<IGeom>& ig
 	}
 
 	/* Determination of interaction */
-	if (D < 0) { //spheres do not "touch" !
-	  if ( !phys->isCohesive ) 
-	  { 
-	    return false;
+	if (D < 0) { //spheres do not touch 
+	  if ( !phys->isCohesive) {
+	    if (!neverErase) return false;
+	    else {
+	      phys->shearForce = Vector3r::Zero();
+	      phys->normalForce = Vector3r::Zero();
+	      phys->isCohesive =0;
+	      phys->FnMax = 0;
+	      phys->FsMax = 0;
+	      return true;
+	    }
 	  }
 	  
 	  if ( phys->isCohesive && (phys->FnMax>0) && (std::abs(D)>Dtensile) ) {
@@ -76,11 +92,22 @@ bool Law2_ScGeom_JCFpmPhys_JointedCohesiveFrictionalPM::go(shared_ptr<IGeom>& ig
 	      file << boost::lexical_cast<string> ( scene->iter )<<" "<< boost::lexical_cast<string> ( geom->contactPoint[0] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[1] ) <<" "<< boost::lexical_cast<string> ( geom->contactPoint[2] ) <<" "<< 0 <<" "<< boost::lexical_cast<string> ( 0.5*(geom->radius1+geom->radius2) ) <<" "<< boost::lexical_cast<string> ( crackNormal[0] ) <<" "<< boost::lexical_cast<string> ( crackNormal[1] ) <<" "<< boost::lexical_cast<string> ( crackNormal[2] ) << endl;
 	    }
 	    cracksFileExist=true;
-
-	    // delete contact
-	    return false;
+	    /// Timos
+	    if (!neverErase) return false; 
+	    else 
+	    {
+	      phys->shearForce = Vector3r::Zero();
+	      phys->normalForce = Vector3r::Zero();
+	      phys->isCohesive =0;
+	      phys->FnMax = 0;
+	      phys->FsMax = 0;
+	      phys->interactionIsCracked = 1;
+	    }
+	    return true;
 	  }
-	}	  
+	}
+// 	phys->crackJointAperture = D;
+	phys->crackJointAperture = -D;
 	
 	/* NormalForce */
 	Real Fn = 0;
@@ -141,15 +168,18 @@ bool Law2_ScGeom_JCFpmPhys_JointedCohesiveFrictionalPM::go(shared_ptr<IGeom>& ig
 	    cracksFileExist=true;
 	    
 	    // delete contact if in tension, set the contact properties to friction if in compression
-	    if ( D < 0 )
-	    {
-	      return false;
-	    } 
-	    else 
-	    {
-	      phys->FnMax = 0;
-	      phys->FsMax = 0;
-	      phys->isCohesive=false;
+	    if ( D < 0 ) { 
+	      if (!neverErase) return false;
+	      else 
+	      {
+		phys->shearForce = Vector3r::Zero();
+		phys->normalForce = Vector3r::Zero();
+		phys->isCohesive =0;
+		phys->FnMax = 0;
+		phys->FsMax = 0;
+		phys->interactionIsCracked=1;
+		return true;
+	      }
 	    }
 	  }
 	}
