@@ -4,9 +4,9 @@
 
 #include<boost/lambda/lambda.hpp>
 
-#include "yade/lib/base/Math.hpp"
-#include "yade/lib/base/Logging.hpp"
-#include "yade/core/Body.hpp"
+#include "lib/base/Math.hpp"
+#include "lib/base/Logging.hpp"
+#include "core/Body.hpp"
 
 #include<boost/function.hpp>
 
@@ -119,7 +119,7 @@ class Shop{
 		
 		//! Function to compute overall ("macroscopic") stress.
 		static Matrix3r getStress(Real volume=0);
-		static Matrix3r getCapillaryStress(Real volume=0);
+		static Matrix3r getCapillaryStress(Real volume=0, bool mindlin=false);
 		static Matrix3r stressTensorOfPeriodicCell() { LOG_WARN("Shop::stressTensorOfPeriodicCelli is DEPRECATED: use getStress instead"); return Shop::getStress(); }
 		//! Compute overall ("macroscopic") stress of periodic cell, returning 2 tensors
 		//! (contribution of normal and shear forces)
@@ -143,4 +143,8 @@ class Shop{
 		//! Change of size of a single sphere or a clump
 		// DEPREC, update wrt growParticles()
 		static void growParticle(Body::id_t bodyID, Real multiplier, bool updateMass);
+		
+		/* \todo implement groupMask */
+		static py::tuple aabbExtrema(Real cutoff=0.0, bool centers=false);
 };
+
