@@ -2,46 +2,49 @@
 #include"Shop.hpp"
 #include<boost/tokenizer.hpp>
 
-#include"yade/core/Scene.hpp"
-#include"yade/core/Body.hpp"
-#include"yade/core/Interaction.hpp"
+#include"core/Scene.hpp"
+#include"core/Body.hpp"
+#include"core/Interaction.hpp"
 
-#include"yade/pkg/common/Aabb.hpp"
-#include"yade/core/Clump.hpp"
-#include"yade/pkg/common/InsertionSortCollider.hpp"
+#include"pkg/common/Aabb.hpp"
+#include"core/Clump.hpp"
+#include"pkg/common/InsertionSortCollider.hpp"
 
-#include"yade/pkg/common/Box.hpp"
-#include"yade/pkg/common/Sphere.hpp"
-#include"yade/pkg/common/ElastMat.hpp"
-#include"yade/pkg/dem/ViscoelasticPM.hpp"
-#include"yade/pkg/dem/CapillaryPhys.hpp"
+#include"pkg/common/Box.hpp"
+#include"pkg/common/Sphere.hpp"
+#include"pkg/common/ElastMat.hpp"
+#include"pkg/dem/ViscoelasticPM.hpp"
+#include"pkg/dem/CapillaryPhys.hpp"
 
-#include"yade/pkg/common/Bo1_Aabb.hpp"
-#include"yade/pkg/dem/NewtonIntegrator.hpp"
-#include"yade/pkg/dem/Ig2_Sphere_Sphere_ScGeom.hpp"
-#include"yade/pkg/dem/Ig2_Box_Sphere_ScGeom.hpp"
-#include"yade/pkg/dem/FrictPhys.hpp"
+#include"pkg/common/Bo1_Aabb.hpp"
+#include"pkg/dem/NewtonIntegrator.hpp"
+#include"pkg/dem/Ig2_Sphere_Sphere_ScGeom.hpp"
+#include"pkg/dem/Ig2_Box_Sphere_ScGeom.hpp"
+#include"pkg/dem/FrictPhys.hpp"
 
-#include"yade/pkg/common/ForceResetter.hpp"
+#include"pkg/common/ForceResetter.hpp"
 
-#include"yade/pkg/common/Dispatching.hpp"
-#include"yade/pkg/common/InteractionLoop.hpp"
-#include"yade/pkg/common/GravityEngines.hpp"
+#include"pkg/common/Dispatching.hpp"
+#include"pkg/common/InteractionLoop.hpp"
+#include"pkg/common/GravityEngines.hpp"
 
-#include"yade/pkg/dem/GlobalStiffnessTimeStepper.hpp"
-#include"yade/pkg/dem/ElasticContactLaw.hpp"
+#include"pkg/dem/GlobalStiffnessTimeStepper.hpp"
+#include"pkg/dem/ElasticContactLaw.hpp"
 
-#include"yade/pkg/dem/ScGeom.hpp"
-#include"yade/pkg/dem/FrictPhys.hpp"
+#include"pkg/dem/ScGeom.hpp"
+#include"pkg/dem/FrictPhys.hpp"
 
-#include"yade/pkg/common/Grid.hpp"
+#include"pkg/common/Grid.hpp"
 
-#include"yade/pkg/dem/Tetra.hpp"
+#include"pkg/dem/Tetra.hpp"
 
 #ifdef YADE_OPENGL
-	#include"yade/pkg/common/Gl1_NormPhys.hpp"
+	#include"pkg/common/Gl1_NormPhys.hpp"
 #endif
 
+#include "py/_utils.hpp"
+
+
 CREATE_LOGGER(Shop);
 
 /*! Flip periodic cell by given number of cells.
@@ -320,8 +323,12 @@ Real Shop::getPorosity(const shared_ptr<Scene>& _scene, Real _volume){
 	const shared_ptr<Scene> scene=(_scene?_scene:Omega::instance().getScene());
 	Real V;
 	if(!scene->isPeriodic){
-		if(_volume<=0) throw std::invalid_argument("utils.porosity must be given (positive) *volume* for aperiodic simulations.");
-		V=_volume;
+		if(_volume<=0){// throw std::invalid_argument("utils.porosity must be given (positive) *volume* for aperiodic simulations.");
+		  py::tuple extrema = aabbExtrema();
+		  V = py::extract<Real>( (extrema[1][0] - extrema[0][0])*(extrema[1][1] - extrema[0][1])*(extrema[1][2] - extrema[0][2]) );
+		}
+		else
+		  V=_volume;
 	} else {
 		V=scene->cell->getVolume();
 	}
