@@ -3,8 +3,8 @@
 #pragma once
 
 
-#include<yade/lib/base/Logging.hpp>
-#include<yade/lib/base/Math.hpp>
+#include<lib/base/Logging.hpp>
+#include<lib/base/Math.hpp>
 
 /*! Class representing geometry of spherical packing, with some utility functions. */
 class SpherePack{
