@@ -1,7 +1,7 @@
 // 2009 © Václav Šmilauer <eudoxos@arcig.cz>
-#include<yade/lib/base/Logging.hpp>
-#include<yade/lib/base/Math.hpp>
-#include<yade/lib/pyutil/doc_opts.hpp>
+#include<lib/base/Logging.hpp>
+#include<lib/base/Math.hpp>
+#include<lib/pyutil/doc_opts.hpp>
 
 namespace py=boost::python;
 
