@@ -751,7 +751,7 @@ If the last point's x coord is zero, it will not be duplicated."""
 def _deprecatedUtilsFunction(old,new):
 	"Wrapper for deprecated functions, example below."
 	import warnings
-	warnings.warn('Function utils.%s is deprecated, use %s instead.'%(old,new),stacklevel=2,category=DeprecationWarning)
+	warnings.warn('Function utils.%s is deprecated, use %s instead.'%(old,new),stacklevel=2,category=UserWarning)
 
 # example of _deprecatedUtilsFunction usage:
 #
@@ -936,7 +936,9 @@ def psd(bins=5, mass=True, mask=-1):
 			if ((2*b.shape.radius)	> maxD) : maxD = 2*b.shape.radius
 			if (((2*b.shape.radius)	< minD) or (minD==0.0)): minD = 2*b.shape.radius
 
-	if (minD==maxD): return false       #All particles are having the same size
+	if (minD==maxD):
+		print 'Monodisperse packing with diameter =', minD,'. Not computing psd'
+		return False       #All particles are having the same size
   
 	binsSizes = numpy.linspace(minD, maxD, bins+1)
 	
